Last active
June 20, 2017 09:20
-
-
Save jd/0413dbceb19080f03854cef09f6861ab to your computer and use it in GitHub Desktop.
Revert commit 9344612d3cd164317170b6189ec43175757e4231 of Emacs
This file contains hidden or bidirectional Unicode text that may be interpreted or compiled differently than what appears below. To review, open the file in an editor that reveals hidden Unicode characters.
Learn more about bidirectional Unicode characters
--- emacs/src/macfont.m.orig 2017-06-20 11:18:58.000000000 +0200 | |
+++ emacs/src/macfont.m 2017-06-20 11:19:26.000000000 +0200 | |
@@ -2373,9 +2373,9 @@ | |
!= (spacing >= FONT_SPACING_MONO))) | |
continue; | |
- /* Don't use a color bitmap font until it is supported on | |
- free platforms. */ | |
- if (sym_traits & kCTFontTraitColorGlyphs) | |
+ /* Don't use a color bitmap font unless its family is | |
+ explicitly specified. */ | |
+ if ((sym_traits & kCTFontTraitColorGlyphs) && NILP (family)) | |
continue; | |
if (j > 0 |
Sign up for free
to join this conversation on GitHub.
Already have an account?
Sign in to comment